bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 26. Aventiure
___________________________________________________ #### Aventivre wie si mit elsen vnd gelpfraten striten #### vnd wie in gelang
###### 1586 | ### Do si nv waren chomen | alle vffe den sant ### der kvenech begonde vragn | wer sol vns dvrch daz lant ### di rehten wege wisen | daz wir niht irre varn ### do sprach der starche volker | daz sol ich eine bewarn
###### 1587 | ### nv enthaltet ivch sprach hagene | ritter vnde chneht ### man sol frivnden volgen | ia dvnchet ez mich reht ### vil vngefvegiv maere | div tvn ich iv bechant ### wir en chvmen nimmer wider | in bvergonden lant
###### 1588 | ### daz sageten mir zwei merwip | hivte morgen frv ### daz wir niht chomen widere | nv rat ich waz man tv ### daz ir ivch waffent helde | ir svlt ivch wol bewarn ### wir han hi starche fiende | daz wir gewaerliche varn
###### 1589 | ### ich wande an lvgen finden | div wilden merwip ### si iahen daz gesvnder | vnser deheines lip ### wider ze lande choeme | niwan der kappelan ### darvmb ich in wolde so gerne | hivt ertrenchet han
###### 1590 | ### do flvgen disiv maere | von schare ce shar ### des wurden snelle helde | vor leide missevar ### do si begonden sorgen | vf den herten tot ### an dirre hovereise | des gie in waerliche not
###### 1591 | ### da ze moeringen | si waren veber chomen ### da dem elsen vergen | der lip was benomen ### do sprach aber hagene | sit daz ich fiende han ### verdienet vf der straze | wir werden sicherlich bestan
###### 1592 | ### ich slvch den selben vergen | hivte morgen frv ### si wizen wol div maere | nv griffet helde zv ### ob gelpfrat vnd else | hivte hi beste ### vnser ingesinde | daz iz in schaedelich erge
###### 1593 | ### ich erchenne si so chvene | ez wirdet niht verlan ### div ross div svlt ir lazen | deste sanfter gan ### daz des iemen wane | wir vliehen vff den wegen ### des rates wil ich volgen | so sprach giselher der degen
###### 1594 | ### wer sol daz ingesinde | wisen veber lant ### si sprachen daz tv volker | dem ist ez hie wol bechant ### stige vnd straze | der chvene spileman ### e daz mans vollen gerte | man sach gewaffent stan
###### 1595 | ### den snellen videlaere | den helm er vff gebant ### in herlicher varwe | was sin wichgewant ### er bant ovch ce sinem shaffte | ein zeichen daz was rot ### sit chom er mit den kvenegen | in eine groezliche not
###### 1596 | ### do was tot des vergen | gelpfrate chomen ### mit gewissem maere | do het ez ovch vernomen ### else der vil starche | ez was in beden leit ### si sanden nach ir helden | di waren schiere bereit
###### 1597 | ### in vil chvrcen ziten | ich wilz ivch hoeren lan ### sach man zv in riten | di schaden heten getan ### in starchen verlivgen | vil vngefvegiv her ### der chomen gelpferate | wol siben hvndert oder mer
###### 1598 | ### do si ir grimmen fienden | begonden riten nach ### ia beiten si ir herren | den was ein teil ze gach ### nach den chvenen gesten | si wolden anden ir zorn ### des wart der herren frivnde | sider mer verlorn
###### 1599 | ### do hete von tronege hagene | wol gefveget daz ### wi mohte siner mage | ein helt gehveten baz ### er pflach der nachhvte | mit den sinen man ### vnd danchwart sin brvder | daz was vil wislich getan
###### 1600 | ### in was des tages cervnnen | des en heten si niht mer ### er vorhte an sinen vrivnden | leit vnde ser ### si riten vnder shilden | dvrch der beyrlant ### danach in chvrcer wile | di helde wurden angerant
###### 1601 | ### beidenthalp der straze | vnd hinden vaste nach ### si horten hveue chlaffen | dem livte was ce gach ### do sprach der chvene danchwart | man wil vns hi bestan ### nv bintet vf di helme | daz dvnchet mich raetlich getan
###### 1602 | ### si hielten ab ir verte | als iz mvste sin ### si sahen in der finster | der liehten schilde schin ### do ne wolde hagene | niht langer si verdagen ### wer iaget vns vf der straze | daz mvs im gelpfrat do sagen
###### 1603 | ### do sprach der margrave | vz beyerlant ### wir svchen vnser viende | vnde haben hernach gerant ### ine weiz niht wer mir hivte | minen vergen slvch ### der was ein helt cen handen | des ist mir leide genvch
###### 1604 | ### do sprach von tronege hagen | was der verge din ### der wold vns niht fveren | des ist div schvlde min ### do slvch ich den recken | deiswar des gie mir not ### ich het von sinen handen | vil nach gewunnen den tot
###### 1605 | ### ich bot im ce miete | golt vnd gewant ### daz er vns vberfvrte | helt in din lant ### do zvrnde er so sere | daz er mich do slvch ### mit einer starchen shaltn | des was ih grimme genvch
###### 1606 | ### do chom ich cem swerte | vnd wert im sinen zorn ### mit einen starchen wunden | des wart der helt verlorn ### daz bringe ich iv ce svne | swi ivch dvnchet gvt ### do gie ez an ein striten | si warn herte gemvt
###### 1607 | ### ich wesse wol sprach gelpfrat | do hi fver gereit ### gventher vnd sin gesinde | daz vns taete leit ### hagen von tronege | nv sol er niht genesen ### fver des vergen ende | der helt mvz hi pverge wesen
###### 1608 | ### si neigeten veber schilde | ce stichen nv div sper ### gelpfrat vnd hagene | in was zein ander ger ### else vnd danchwart | vil herliche riten ### si versvchten wer si waren | da wart vil grimme gestriten
###### 1609 | ### wi moehten sich versvchen | immer helde baz ### von einer starchen tioste | hinder daz ross gesaz ### hagen der chven | von gelpfrates hant ### im brast daz fverbvege | do wart im striten bechant
###### 1610 | ### von ir ingesinde | der crach der sheffte shal ### do erholt ovch sich do hagane | der e was ce tal ### chomen von dem stiche | nider an daz gras ### er waene vnsanftes mvtes | wider gelpfrate was
###### 1611 | ### wer in div ross behielte | daz ist mir vmbechant ### si waren zv der erden | chomn vf den sant ### hagen vnd gelpfrat | einander lieffen an ### des hvlfen ir gesellen | daz in wart striten chvnt getan
###### 1612 | ### swi pitterliche hagen | ce gelpfrate spranch ### der edel margrave | des schildes hin im swanch ### ein michel stvche | deiz fiwer draete dan ### des was vil nach erstorben | der chven gventheres man
###### 1613 | ### do begonde er rveffen | danchwarten an ### hilf mir lieber brvder | ia hat mich bestan ### ein helt cen sinen handen | dern lat mich niht genesen ### do sprach der chven danchwart | des sol ich sheidaer wesen
###### 1614 | ### der helt do spranch dar naher | vnd slvch im einen slach ### mit einem sharffen waffen | davon er tot gelach ### else wolde gerne | rechen do den man ### er vnd sin gesinde | schieden shedeliche dan
###### 1615 | ### im was erslagen der brvder | selbe wart er wunt ### wol ahzech siner degene | beliben da cestvnt ### mit dem grimmen tode | der herre mvose dan ### flvhtechlichen | von den gventheres man
###### 1616 | ### do di von beyerlande | wichen vz dem wege ### do hort man nachhellen | di vreislichen slege ### do iageten di von tronege | ir fianden nach ### di sin niht en kelten wandn | den was allen ce gach
###### 1617 | ### do sprach an der flvehte | danchwart der degen ### wir svln wider wenden | balde vf disen wegen ### vnd laze wir si riten | si sint von blvte naz ### gahe wir cen frivnden | ich rate waerlichen daz
###### 1618 | ### do si hin wider chomen | da der shade was geshehen ### do sprach von tronege hagene | helde ir svlt besehen ### wes vns hi gebreste | oder wen wir han verlorn ### hi in disem strite | dvrh den gelpfrades zorn
###### 1619 | ### si heten vlorn viere | di mvsen si verchlagen ### di waren wol vergolten | da wider was erslagen ### der von beyerlande | hvndert oder baz ### des waren den von tronege | ir schilde trvebe vnd blvtes naz
###### 1620 | ### ein teil schein vz den wolchen | des liehten manen prehen ### do sprach aber hagene | niemen sol veriehen ### den minen lieben herren | waz wir hi han getan ### lat siv vnze morgen | ane sorge bestan
###### 1621 | ### do si nv nach in chomen | di dort striten e ### do tet dem ingesinde | div mvede harte we ### wi lange svl wir riten | sprach manich man ### do sprach der chvene danchwart | wir mvgen niht herberge han
###### 1622 | ### ir mvezet alle riten | vnz ez werde tach ### volker der snelle | der des gesindes pflach ### bat den marshalch vragen | wa svl wir hinte sin ### da gerasten vnser moere | vnd ovch di liebn herren min
###### 1623 | ### do sprach der chvene danchwart | ine chans iv niht gesagen ### wir en mvegen niht geruwen | e iz beginne tagen ### swa wirz danne vinden | da legen vns an ein gras ### do si div maere horten | wi leit in svemelichen was
###### 1624 | ### si beliben vnvermeldet | des heizen blvtes rot ### vnz daz div svnne | ir liehtez schinen bot ### dem morgen veber berge | daz ez der kvenich sach ### daz si gestriten heten | der helt vil zornechlichen sprach
###### 1625 | ### wi nv frivnt hagene | iv waen versmahet daz ### daz ich pi iv waere | da iv di ringe naz ### svs wurden von dem blvte | wer hat daz getan ### er sprach daz tet else | der het vns naehten bestan
###### 1626 | ### dvrch den sinen vergen | wir wurden angerant ### da slvch gelpfraten | mins brvder danchwarten hant ### sit entran vns else | des twang in michel not ### in hvndert vnd vns viere | beliben in dem strite tot
###### 1627 | ### wir chvnnen niht bescheiden | wa si sich leiten nider ### alle di lantlivte | di gevriesshen sider ### daz ze hove fvren | der edeln vten chint ### si wurden wol enpfangen | da ze pazowe sint
###### 1628 | ### der edeln chvenege oheim | der bisshoff pilgrin ### dem wart vil wol ze mvte | do di neven sin ### mit also vil recken | chomen zv zim in daz lant ### daz er in willech waere | daz wart in schier bechant
###### 1629 | ### si wurden wol enpfangen | von vrivnden vf den wegen ### da ze pazowe | man chonde ir niht gepflegen ### si mvsen veberz wazzer | da si fvnden velt ### da wurden vf gespannen | hvtten vnde gecelt
###### 1630 | ### si mvsen da beliben | allen einen tach ### vnd ovch di naht mit vollen | wi shon man ir pflach ### darnach si mvsen riten | in rvedegeres lant ### dem wurden ovch div maere | darnach vil schiere bechant
###### 1631 | ### do di wegemveden | rowe genamen ### vnde si dem lande | naher quamen ### do fvndens vf der marche | slaffende einen man ### dem von tronege hagen | ein starchez waffen an gewan
###### 1632 | ### ia was geheizen eckewart | der starche ritter gvt ### er gewan darvmb | einen trvrigen mvt ### da er verlos daz waffen | von der helde vart ### di march rvedegeres | di fvndens vebele bewart
###### 1633 | ### owe mir dirre schande | sprach do eckewart ### ia riwet mich vil sere | der bvrgonden vart ### sit ich sifride vlos | sit was min frevde cergan ### owe herre rvedger | wi han ich wider dich getan
###### 1634 | ### do hort vil wol hagene | des edelen recken not ### er gab im wider sin waffn | vnd sehs povge rot ### di habe dir helt ce minnen | daz dv min frivnt sist ### dv bist ein degen chvene | swi eine dv vffe der marche list
###### 1635 | ### got lon iv iwerr povge | sprach do ecchewart ### doch riwet mich vil sere | zen hivnen iwer vart ### ir slvget sifriden | man ist hie gehaz ### daz ir ivch wol behvetet | an triwen rat iv ich daz
###### 1636 | ### nv mveze vns got behveten | sprach do hagene ### ian hant niht mere sorge | dise degene ### wan vmb di herberge | di chvenige vnd ovch ir man ### wa wir in disem lande | noch hinte nahtselde han
###### 1637 | ### div ross sint vns verdorben | vf den herten wegen ### vnt der spise cervnnen | sprach hagen der degen ### wir finden iz ninder veile | vns waere wirtes not ### der vns noch hinte gaebe | dvrch sine tvgende sin brot
###### 1638 | ### do sprach aber eckwart | ich zeih iv einen wirt ### daz ir ce hvse selten | so wol bechomen birt ### in deheinem lande | als iv hi mach geschehen ### ob ir vil snelle degene | wellet rvedgern sehen
###### 1639 | ### der sizet vf der straze | vnd ist der beste wirt ### der ie chom ce hvse | sin herce tvgende birt ### also der sveze meye | daz gras mit blvmen tvt ### swenne er sol helden dienen | so ist er vroelich gemvt
###### 1640 | ### do sprach der kvnech gventher | welt ir min bote sin ### ob vns welle enthalten | dvrch den willen min ### min lieber frivnt rvedger | mine mage vnd vnser man ### daz wil ih immer dienen | so ich allerbeste chan
###### 1641 | ### der bote pin ich gerne | sprach do eckewart ### mit vil gvtem willen | hvb er sich an di vart ### vnd sagete do rvedgere | als er het vernomen ### im was in manigen ziten | niht so lieber maere chomen
###### 1642 | ### man sah ce bechelaren | ilen einen degen ### selbe erchande in rvedger | er sprach vf disen wegen ### dort her gahet eckewart | ein criemhilde man ### er wande daz di viende | im heten leide getan
###### 1643 | ### do gi er fver di porten | da er den boten vant ### daz swert er ab gvrte | vnd leitez von der hant ### div maere div er brahte | wurden niht verdaget ### den wirt vnt sine frivnde | ez wart in schiere gesaget
###### 1644 | ### er sprach cem margraven | mich hat zv ziv gesant ### gventher der herre | von bvrgonden lant ### vnd giselher sin brvder | vnd ovch gernot ### der reckn ieslicher | iv sinen dienest her enbot
###### 1645 | ### daz selbe hat ovch hagene | vnd voelker ### mit triwen vlizechliche | noch sage ich iv mer ### daz iv des kveneges marsshalch | bi mir daz enbot ### daz den gvten chnehten | waere iwer herberge not
###### 1646 | ### mit lachendem mvnde | antwurte rvedger ### nv wol mich dirre maere | daz di kvenge her ### daz si gervchent miner dieneste | der wirt in niht verseit ### choment si mir ce hvse | des pin ich vro vnt gemeit
###### 1647 | ### danchwart der marshalch | der hiez ivch wizzen lan ### wen ir ce hvse bmit in soldet han ### sehzech sneller recken | vnd tvsent ritter gvt ### vnd nivn tvsent chnehte | do wart er vrolich gemvt
###### 1648 | ### nv wol mich dirre geste | sprach do rvedeger ### daz mir choment ce hvse | dise geste her ### den ich noch vil selten | iht gedienet han ### nv ritet in engegene | beide mage vnde man
###### 1649 | ### do ilten zn den rossen | ritter vnd kneht ### swaz in gebot ir herre | daz dvhtes alle reht ### do liezen sie in der dienste | zogen deste baz ### noch en weste es niht vrov goetelint | div in ir chemenaten saz

<<< Übersicht <<< vorige Seite nächste Seite >>>